@@ -119,15 +119,16 @@ sub check_heartbeat {
             reason => "Unanswered ping(s): $ping_counter",
         );
     }
+    else {
+        my $ping_message = $self->{'_ping_store'}->add();
 
-    my $ping_message = $self->{'_ping_store'}->add();
+        my $ping = Net::WebSocket::Frame::ping->new(
+            payload => $ping_message,
+            $self->FRAME_MASK_ARGS(),
+        );
 
-    my $ping = Net::WebSocket::Frame::ping->new(
-        payload => $ping_message,
-        $self->FRAME_MASK_ARGS(),
-    );
-
-    $self->_write_frame($ping);
+        $self->_write_frame($ping);
+    }
 
     return;
 }
@@ -229,6 +230,12 @@ sub _handle_control_frame {
         if (!$self->{'_sent_close_frame'}) {
             my ($code, $reason) = $frame->get_code_and_reason();
 
+            if ($code > 4999) {
+                my $reason_chunk = substr( $reason, 0, 50 );
+                $reason = "Invalid close code ($code, reason: $reason_chunk) received.";
+                $code = 'PROTOCOL_ERROR';
+            }
+
             $self->_close_with_frame(
                 Net::WebSocket::Frame::close->new(
                     code => $code,
