@@ -2,7 +2,7 @@ package Net::WebSocket::Frame::continuation;
 
 =encoding utf-8
 
-=HEAD1
+=head1 NAME
 
 Net::WebSocket::Frame::continuation
 
@@ -15,12 +15,12 @@ Net::WebSocket::Frame::continuation
         #Optional, can be either empty (default) or four random bytes
         mask => q<>,
 
-        payload_sr => \$payload,
+        payload => $payload,
     );
 
     $frm->get_type();           #"continuation"
 
-    $frm->is_control_frame();   #0
+    $frm->is_control();   #0
 
     my $mask = $frm->get_mask_bytes();
 
